pub(crate) struct DownloadContext<'a> {Show 15 fields
pub path_modification_cache: Arc<Mutex<HashMap<Vec<&'static str>, PathFreshness>>>,
pub src: &'a Path,
pub rust_info: &'a GitInfo,
pub submodules: &'a Option<bool>,
pub download_rustc_commit: &'a Option<String>,
pub host_target: TargetSelection,
pub llvm_from_ci: bool,
pub target_config: &'a HashMap<TargetSelection, Target>,
pub out: &'a Path,
pub patch_binaries_for_nix: Option<bool>,
pub exec_ctx: &'a ExecutionContext,
pub stage0_metadata: &'a Stage0,
pub llvm_assertions: bool,
pub bootstrap_cache_path: &'a Option<PathBuf>,
pub is_running_on_ci: bool,
}Expand description
Only should be used for pre config initialization downloads.
Fields
path_modification_cache: Arc<Mutex<HashMap<Vec<&'static str>, PathFreshness>>>src: &'a Pathrust_info: &'a GitInfosubmodules: &'a Option<bool>download_rustc_commit: &'a Option<String>host_target: TargetSelectionllvm_from_ci: booltarget_config: &'a HashMap<TargetSelection, Target>out: &'a Pathpatch_binaries_for_nix: Option<bool>exec_ctx: &'a ExecutionContextstage0_metadata: &'a Stage0llvm_assertions: boolbootstrap_cache_path: &'a Option<PathBuf>is_running_on_ci: boolTrait Implementations
Sourceimpl<'a> AsRef<DownloadContext<'a>> for DownloadContext<'a>
impl<'a> AsRef<DownloadContext<'a>> for DownloadContext<'a>
Sourcefn as_ref(&self) -> &DownloadContext<'a>
fn as_ref(&self) -> &DownloadContext<'a>
Converts this type into a shared reference of the (usually inferred) input type.